==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Agent/src/com/clustercontrol/agent/ReceiveTopic.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.agent;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Properties;
import java.util.Timer;
import java.util.TimerTask;

import javax.jms.ExceptionListener;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.ObjectMessage;
import javax.jms.Session;
import javax.jms.Topic;
import javax.jms.TopicConnection;
import javax.jms.TopicConnectionFactory;
import javax.jms.TopicSession;
import javax.jms.TopicSubscriber;
import javax.naming.InitialContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.agent.util.RunHistoryUtil;
import com.clustercontrol.jobmanagement.bean.CommandConstant;
import com.clustercontrol.jobmanagement.bean.CommandTypeConstant;
import com.clustercontrol.jobmanagement.bean.RunStatusConstant;
import com.clustercontrol.jobmanagement.bean.TopicConstant;
import com.clustercontrol.jobmanagement.message.RunInstructionInfo;
import com.clustercontrol.jobmanagement.message.RunResultInfo;



/**
 * Topic饹
 * Topicؤ³ȡåμԤ
 * @version $Revision: 1.16 $
 * @since 1.0.0
 * 
 */
public class ReceiveTopic implements MessageListener, ExceptionListener {

	private static long RETRY_INTERVAL = 10000;

	private static final String TOPIC_CON_FACTORY = "ConnectionFactory";
	private static final String TOPIC_USER_NAME = "topic.user.name";
	private static final String TOPIC_USER_PASSWORD = "topic.user.password";

	protected ArrayList m_facilityIdList;
    protected SendQueue m_sendQueue;
    
    protected static Hashtable<String, Date> m_runHistory;

	private Properties m_props;

	private TopicConnectionFactory m_factory;

    protected TopicConnection m_con;
    protected Topic m_topic;
    protected TopicSession m_session;
    protected TopicSubscriber m_subscriber;
	
	private boolean m_errFlg = false;

	/** åӥ³ѥޡ * */
	protected static Timer m_timer = new Timer(true);

	//
	private static Log log = LogFactory.getLog(ReceiveTopic.class);
	
	/**
	 * 󥹥ȥ饯
	 * @param facilityIdList եƥIDΥꥹȡ
	 * @param sendQueueåѥ饹
	 * @param propsץѥƥե
	 */
	@SuppressWarnings("unchecked")
	public ReceiveTopic(Collection facilityIdList, SendQueue sendQueue, Properties props) {
		super();
		m_facilityIdList = new ArrayList(facilityIdList);
		m_sendQueue = sendQueue;
		m_props = props;
		m_runHistory = new Hashtable<String, Date>();

		//³
        initial();
	}
    
    
    /**
     * եƥIDꥹ.
     * ꤵ줿եƥIDΥꥹȤȰ㤦ϡȥԥåκ³Ԥ
     * @param facilityIdList
     * @since
     */
	@SuppressWarnings("unchecked")
	synchronized public void setFacilityIdList(Collection facilityIdList) {
	
		//ѲƤ뤫ɤǧ
		if(facilityIdList.size() == m_facilityIdList.size()){
			if( m_facilityIdList.containsAll(facilityIdList) ){
				return;
			}
		}
		
		//եƥꥹȹ
		m_facilityIdList = new ArrayList(facilityIdList);
		//Topic³
		if( !isErrFlg() ){
		    initialTopic();
		}
	}
    /* 
     * ȥԥå
     * (non-Javadoc)
     * @see javax.jms.MessageListener#onMessage(javax.jms.Message)
     */
    public void onMessage(Message message) {
        
        
        log.debug("onMessage start");
        
        if(message instanceof ObjectMessage){
            ObjectMessage objectMessage = (ObjectMessage)message;
            Object obj;
			try {
				obj = objectMessage.getObject();
			} catch (JMSException e) {
				log.error("å", e);
				return;
			}

			if(obj instanceof RunInstructionInfo){
            	log.debug("onMessage get RunInstructionInfo");
                
                RunInstructionInfo info = (RunInstructionInfo)obj;
                
                log.debug("onMessage SessionID=" + info.getSessionId() + ", JobID=" + info.getJobId());
                
                if(info.getCommandType() == CommandTypeConstant.CHECK){
                	//å
                	log.debug("onMessage CommandType = CHECK");
                    
                    RunResultInfo resultInfo = new RunResultInfo();
                    resultInfo.setSessionId(info.getSessionId());
                    resultInfo.setJobId(info.getJobId());
                    resultInfo.setFacilityId(info.getFacilityId());
                    resultInfo.setCommandType(info.getCommandType());
	                
                    m_sendQueue.put(resultInfo);
                }
                else if(info.getCommandType() == CommandTypeConstant.DELETE_NORMAL_HISTORY || 
                		info.getCommandType() == CommandTypeConstant.DELETE_STOP_HISTORY){
                	//¹
                	RunHistoryUtil.delRunHistory(info, m_runHistory);
                }
                else {
                	log.debug("onMessage CommandType != CHECK");
                	
                	//¹å
                	Date startDate = RunHistoryUtil.findRunHistory(info, m_runHistory);
                	if(startDate != null){
                		//¹򤬤硢ϥå
                		
                		RunResultInfo resultInfo = new RunResultInfo();
                		resultInfo.setSessionId(info.getSessionId());
                		resultInfo.setJobId(info.getJobId());
                		resultInfo.setFacilityId(info.getFacilityId());
                		resultInfo.setCommand(info.getCommand());
                		resultInfo.setCommandType(info.getCommandType());
                		resultInfo.setStatus(RunStatusConstant.START);
                		resultInfo.setTime(startDate);
                		
                		log.info("run SessionID=" + info.getSessionId() + ", JobID=" + info.getJobId());

                		//
                		m_sendQueue.put(resultInfo);
                	}
                	else{
	                	if(info.getCommand().equals(CommandConstant.GET_PUBLIC_KEY) || 
	                			info.getCommand().equals(CommandConstant.ADD_PUBLIC_KEY) || 
	                			info.getCommand().equals(CommandConstant.DELETE_PUBLIC_KEY)){
	                    	//ѥåɼ¹
	                    	log.debug("onMessage CommandType = GET_PUBLIC_KEY or ADD_PUBLIC_KEY or DELETE_PUBLIC_KEY");
	                    	
	                    	PublicKeyThread thread = new PublicKeyThread(info, m_sendQueue, m_runHistory, m_props);
	    	                thread.start();
	                    }
	                	else if(info.getCommand().equals(CommandConstant.GET_FILE_LIST)){
	                    	//եꥹѥåɼ¹
	                    	log.debug("onMessage CommandType = GET_FILE_LIST");
	                    	
	                    	FileListThread thread = new FileListThread(info, m_sendQueue, m_runHistory, m_props);
	    	                thread.start();
	                    }
	                	else if(info.getCommand().equals(CommandConstant.GET_CHECKSUM) || 
	                			info.getCommand().equals(CommandConstant.CHECK_CHECKSUM)){
	                    	//åѥåɼ¹
	                    	log.debug("onMessage CommandType = GET_CHECKSUM or CHECK_CHECKSUM");
	                    	
	                    	CheckSumThread thread = new CheckSumThread(info, m_sendQueue, m_runHistory, m_props);
	    	                thread.start();
	                    }
	                	else{
	                    	//ޥɼ¹
	    	                CommandThread thread = new CommandThread(info, m_sendQueue, m_runHistory, m_props);
	    	                thread.start();
	                	}
                	}
                }
            }else{
				log.error("å" + obj.toString());
				return;
            }
        }else{
			log.error("å" + message.getClass());
			return;
        }
        log.debug("onMessage end");
    }
    
    /* ̿顼ϥɥ
     * (non-Javadoc)
     * @see javax.jms.ExceptionListener#onException(javax.jms.JMSException)
     */
    public void onException(JMSException arg0) {

    	log.error(arg0);
    	
        setErrFlg(true);
    }

    /**
	 * @param errFlg
	 *            errFlg ꡣ
	 */
	synchronized private void setErrFlg(boolean errFlg) {
		if (m_errFlg == false && errFlg == true) {

			m_timer.schedule(new ReSetupTask(), RETRY_INTERVAL,
					RETRY_INTERVAL);

		}
		m_errFlg = errFlg;
	}

	/**
	 * @return errFlg ᤷޤ
	 */
	synchronized private boolean isErrFlg() {
		return m_errFlg;
	}
	/**
	 *  
	 */
	synchronized private boolean reInitial() {

		boolean ret = false;

		log.info("³!");

		terminate();

		if (initial()) {

			ret = true;

			log.info("³:!");

			//顼ե饰
			setErrFlg(false);


		} else {
			log.info("³:!");
		}

		return ret;
	}
	/**
	 * ³νλ
	 *  
	 */
	public void terminate() {

		terminateSumscriber();

		
        try {
			if (m_session != null)
				m_session.close();
		} catch (JMSException e) {
		}

		try {
			if (m_con != null)
				m_con.close();
		} catch (JMSException e1) {
		}
	}
	/**
	 * ȥԥåνλ 
	 */
	private void terminateSumscriber() {
		try {
			if (m_subscriber != null)
		        m_subscriber.close();
		} catch (JMSException e) {
		}
	}



	/**
	 * 
	 * JMSؤ³ȥԥåԤ
	 * @return
	 */
	private boolean initial() {

		log.info("EJB³");

		InitialContext con = null;

		try {
			//InitialContext
			con = new InitialContext(m_props);

			//ͥեȥ
			m_factory = (TopicConnectionFactory) con.lookup(TOPIC_CON_FACTORY);

			//ͥ
			if (m_props.getProperty(TOPIC_USER_NAME) != null) {
				//桼ǧ
				m_con = m_factory.createTopicConnection(m_props
						.getProperty(TOPIC_USER_NAME), m_props
						.getProperty(TOPIC_USER_PASSWORD));
			} else {
				//桼ǧڤʤ
				m_con = m_factory.createTopicConnection();
			}

			
			//å
			m_session = m_con.createTopicSession(false,
					Session.AUTO_ACKNOWLEDGE);

			//åTopic
			m_topic = (Topic) con.lookup(TopicConstant.TOPIC_NAME_EXECUTE);

			
			//顼ϥɤ饻å
	        m_con.setExceptionListener(this);

	        m_con.start();

	        //ȥԥå³
	        initialTopic();
			

		} catch (Exception e) {
			log.error("Init", e);
			setErrFlg(true);
			return false;
		} finally {
			try {
				if (con != null)
					con.close();
			} catch (Exception e1) {
			}
		}
		return true;

	}

	/**
	 * ȥԥå
	 * @return
	 * @since
	 */
	private boolean initialTopic() {


		//ߤTopicλ
		terminateSumscriber();
		
		//եƥIDǥȥԥå
		try {
	        
	        //եƥIDǥå쥯
	        StringBuffer msgSelector = new StringBuffer();
	        for (Iterator iter = m_facilityIdList.iterator(); iter.hasNext();) {
				String facilityId = (String) iter.next();
				msgSelector.append("FacilityId='");
				msgSelector.append(facilityId);
				msgSelector.append("'");
				if( iter.hasNext() ){
					msgSelector.append(" OR ");
				}
			}
	        
	        if(msgSelector.length() != 0){
	        
		        m_subscriber = m_session.createSubscriber(m_topic, msgSelector.toString(), false);
		        
		        //ХåϿ
		        m_subscriber.setMessageListener(this);

	        }else{
	        	log.debug("եƥ󤬤ʤΤǡ⤷ʤ");
	        }
			

		} catch (Exception e) {
			log.error("TopicInit", e);
			setErrFlg(true);
			return false;
		} finally {
		}
		return true;

	}
	/**
	 * EJB³ޡ
	 * ̿顼ȤʤäǸƤФ³Ԥ 
	 */
	protected class ReSetupTask extends TimerTask {

		/**
		 * ͥ󥯥
		 */
		public void run() {
			if (reInitial()) {
				//Υ򥿥ޡ
				cancel();
			}
		}

	}
	
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Agent/src/com/clustercontrol/agent/ReceiveTopic.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.agent;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Properties;
import java.util.Timer;
import java.util.TimerTask;

import javax.jms.ExceptionListener;
import javax.jms.JMSException;
import javax.jms.Message;
import javax.jms.MessageListener;
import javax.jms.ObjectMessage;
import javax.jms.Session;
import javax.jms.Topic;
import javax.jms.TopicConnection;
import javax.jms.TopicConnectionFactory;
import javax.jms.TopicSession;
import javax.jms.TopicSubscriber;
import javax.naming.InitialContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.clustercontrol.agent.util.RunHistoryUtil;
import com.clustercontrol.jobmanagement.bean.CommandConstant;
import com.clustercontrol.jobmanagement.bean.CommandTypeConstant;
import com.clustercontrol.jobmanagement.bean.RunStatusConstant;
import com.clustercontrol.jobmanagement.bean.TopicConstant;
import com.clustercontrol.jobmanagement.message.RunInstructionInfo;
import com.clustercontrol.jobmanagement.message.RunResultInfo;



/**
 * Topic受信クラス
 * Topicへの接続と、メッセージの受信を行う。
 * @version $Revision: 1.2 $
 * @since 1.0.0
 * 
 */
public class ReceiveTopic implements MessageListener, ExceptionListener {

	private static long RETRY_INTERVAL = 10000;

	private static final String TOPIC_CON_FACTORY = "ConnectionFactory";
	private static final String TOPIC_USER_NAME = "topic.user.name";
	private static final String TOPIC_USER_PASSWORD = "topic.user.password";

	protected ArrayList m_facilityIdList;
    protected SendQueue m_sendQueue;
    
    protected static Hashtable<String, Date> m_runHistory;

	private Properties m_props;

	private TopicConnectionFactory m_factory;

    protected TopicConnection m_con;
    protected Topic m_topic;
    protected TopicSession m_session;
    protected TopicSubscriber m_subscriber;
	
	private boolean m_errFlg = false;

	/** メッセージサービス再接続用タイマー * */
	protected static Timer m_timer = new Timer(true);

	//ロガー
	private static Log log = LogFactory.getLog(ReceiveTopic.class);
	
	/**
	 * コンストラクタ
	 * @param facilityIdList ファシリティIDのリスト　
	 * @param sendQueue　メッセージ送信用クラス
	 * @param props　プロパティファイル情報
	 */
	@SuppressWarnings("unchecked")
	public ReceiveTopic(Collection facilityIdList, SendQueue sendQueue, Properties props) {
		super();
		m_facilityIdList = new ArrayList(facilityIdList);
		m_sendQueue = sendQueue;
		m_props = props;
		m_runHistory = new Hashtable<String, Date>();

		//接続処理
        initial();
	}
    
    
    /**
     * ファシリティIDリスト設定.
     * 設定されたファイシリティIDのリストが、前回と違う場合は、トピック受信の再接続を行う
     * @param facilityIdList　
     * @since
     */
	@SuppressWarnings("unchecked")
	synchronized public void setFacilityIdList(Collection facilityIdList) {
	
		//取得した情報が変化しているかどうか確認
		if(facilityIdList.size() == m_facilityIdList.size()){
			if( m_facilityIdList.containsAll(facilityIdList) ){
				return;
			}
		}
		
		//ファイシリティリスト更新
		m_facilityIdList = new ArrayList(facilityIdList);
		//Topic再接続
		if( !isErrFlg() ){
		    initialTopic();
		}
	}
    /* 
     * トピック受信処理
     * (non-Javadoc)
     * @see javax.jms.MessageListener#onMessage(javax.jms.Message)
     */
    public void onMessage(Message message) {
        
        
        log.debug("onMessage start");
        
        if(message instanceof ObjectMessage){
            ObjectMessage objectMessage = (ObjectMessage)message;
            Object obj;
			try {
				obj = objectMessage.getObject();
			} catch (JMSException e) {
				log.error("受信メッセージが不正", e);
				return;
			}

			if(obj instanceof RunInstructionInfo){
            	log.debug("onMessage get RunInstructionInfo");
                
                RunInstructionInfo info = (RunInstructionInfo)obj;
                
                log.debug("onMessage SessionID=" + info.getSessionId() + ", JobID=" + info.getJobId());
                
                if(info.getCommandType() == CommandTypeConstant.CHECK){
                	//受信メッセージ応答
                	log.debug("onMessage CommandType = CHECK");
                    
                    RunResultInfo resultInfo = new RunResultInfo();
                    resultInfo.setSessionId(info.getSessionId());
                    resultInfo.setJobId(info.getJobId());
                    resultInfo.setFacilityId(info.getFacilityId());
                    resultInfo.setCommandType(info.getCommandType());
	                
                    m_sendQueue.put(resultInfo);
                }
                else if(info.getCommandType() == CommandTypeConstant.DELETE_NORMAL_HISTORY || 
                		info.getCommandType() == CommandTypeConstant.DELETE_STOP_HISTORY){
                	//実行履歴削除
                	RunHistoryUtil.delRunHistory(info, m_runHistory);
                }
                else {
                	log.debug("onMessage CommandType != CHECK");
                	
                	//実行履歴チェック
                	Date startDate = RunHistoryUtil.findRunHistory(info, m_runHistory);
                	if(startDate != null){
                		//実行履歴がある場合、開始メッセージを送信する
                		
                		RunResultInfo resultInfo = new RunResultInfo();
                		resultInfo.setSessionId(info.getSessionId());
                		resultInfo.setJobId(info.getJobId());
                		resultInfo.setFacilityId(info.getFacilityId());
                		resultInfo.setCommand(info.getCommand());
                		resultInfo.setCommandType(info.getCommandType());
                		resultInfo.setStatus(RunStatusConstant.START);
                		resultInfo.setTime(startDate);
                		
                		log.info("run SessionID=" + info.getSessionId() + ", JobID=" + info.getJobId());

                		//送信
                		m_sendQueue.put(resultInfo);
                	}
                	else{
	                	if(info.getCommand().equals(CommandConstant.GET_PUBLIC_KEY) || 
	                			info.getCommand().equals(CommandConstant.ADD_PUBLIC_KEY) || 
	                			info.getCommand().equals(CommandConstant.DELETE_PUBLIC_KEY)){
	                    	//公開鍵用スレッド実行
	                    	log.debug("onMessage CommandType = GET_PUBLIC_KEY or ADD_PUBLIC_KEY or DELETE_PUBLIC_KEY");
	                    	
	                    	PublicKeyThread thread = new PublicKeyThread(info, m_sendQueue, m_runHistory, m_props);
	    	                thread.start();
	                    }
	                	else if(info.getCommand().equals(CommandConstant.GET_FILE_LIST)){
	                    	//ファイルリスト用スレッド実行
	                    	log.debug("onMessage CommandType = GET_FILE_LIST");
	                    	
	                    	FileListThread thread = new FileListThread(info, m_sendQueue, m_runHistory, m_props);
	    	                thread.start();
	                    }
	                	else if(info.getCommand().equals(CommandConstant.GET_CHECKSUM) || 
	                			info.getCommand().equals(CommandConstant.CHECK_CHECKSUM)){
	                    	//チェックサム用スレッド実行
	                    	log.debug("onMessage CommandType = GET_CHECKSUM or CHECK_CHECKSUM");
	                    	
	                    	CheckSumThread thread = new CheckSumThread(info, m_sendQueue, m_runHistory, m_props);
	    	                thread.start();
	                    }
	                	else{
	                    	//コマンド実行
	    	                CommandThread thread = new CommandThread(info, m_sendQueue, m_runHistory, m_props);
	    	                thread.start();
	                	}
                	}
                }
            }else{
				log.error("受信メッセージが不正" + obj.toString());
				return;
            }
        }else{
			log.error("受信メッセージが不正" + message.getClass());
			return;
        }
        log.debug("onMessage end");
    }
    
    /* 通信エラーハンドラ
     * (non-Javadoc)
     * @see javax.jms.ExceptionListener#onException(javax.jms.JMSException)
     */
    public void onException(JMSException arg0) {

    	log.error(arg0);
    	
        setErrFlg(true);
        
        terminate();     
    }

    /**
	 * @param errFlg
	 *            errFlg を設定。
	 */
	synchronized private void setErrFlg(boolean errFlg) {
		if (m_errFlg == false && errFlg == true) {

			m_timer.schedule(new ReSetupTask(), RETRY_INTERVAL,
					RETRY_INTERVAL);

		}
		m_errFlg = errFlg;
	}

	/**
	 * @return errFlg を戻します。
	 */
	synchronized private boolean isErrFlg() {
		return m_errFlg;
	}
	/**
	 *  
	 */
	synchronized private boolean reInitial() {

		boolean ret = false;

		log.info("再接続処理!");

		terminate();

		if (initial()) {

			ret = true;

			log.info("再接続処理:成功!");

			//エラーフラグ解除
			setErrFlg(false);


		} else {
			log.info("再接続処理:失敗!");
		}

		return ret;
	}
	/**
	 * サーバ接続の終了処理
	 *  
	 */
	public void terminate() {

		terminateSumscriber();

		
        try {
			if (m_session != null)
				m_session.close();
		} catch (JMSException e) {
		}

		try {
			if (m_con != null)
				m_con.close();
		} catch (JMSException e1) {
		}
	}
	/**
	 * トピック受信処理の終了 
	 */
	private void terminateSumscriber() {
		try {
			if (m_subscriber != null)
		        m_subscriber.close();
		} catch (JMSException e) {
		}
	}



	/**
	 * 初期化処理
	 * JMSへの接続、トピック受信設定を行う
	 * @return
	 */
	private boolean initial() {

		log.info("EJB接続初期化");

		InitialContext con = null;

		try {
			//InitialContextの生成
			con = new InitialContext(m_props);

			//コネクションファクトリ生成
			m_factory = (TopicConnectionFactory) con.lookup(TOPIC_CON_FACTORY);

			//コネクション生成
			if (m_props.getProperty(TOPIC_USER_NAME) != null) {
				//ユーザ認証
				m_con = m_factory.createTopicConnection(m_props
						.getProperty(TOPIC_USER_NAME), m_props
						.getProperty(TOPIC_USER_PASSWORD));
			} else {
				//ユーザ認証なし
				m_con = m_factory.createTopicConnection();
			}

			
			//セッション生成
			m_session = m_con.createTopicSession(false,
					Session.AUTO_ACKNOWLEDGE);

			//メッセージTopic取得
			m_topic = (Topic) con.lookup(TopicConstant.TOPIC_NAME_EXECUTE);

			
			//エラーハンドらセット
	        m_con.setExceptionListener(this);

	        m_con.start();

	        //トピック接続開始
	        initialTopic();
			

		} catch (Exception e) {
			log.error("Init", e);
			setErrFlg(true);
			return false;
		} finally {
			try {
				if (con != null)
					con.close();
			} catch (Exception e1) {
			}
		}
		return true;

	}

	/**
	 * トピック受信設定
	 * @return
	 * @since
	 */
	private boolean initialTopic() {


		//現在のTopic受信を終了
		terminateSumscriber();
		
		//新しいファシリティIDでトピック受信開始
		try {
	        
	        //ファシリティIDでメッセージセレクターを作成
	        StringBuffer msgSelector = new StringBuffer();
	        for (Iterator iter = m_facilityIdList.iterator(); iter.hasNext();) {
				String facilityId = (String) iter.next();
				msgSelector.append("FacilityId='");
				msgSelector.append(facilityId);
				msgSelector.append("'");
				if( iter.hasNext() ){
					msgSelector.append(" OR ");
				}
			}
	        
	        if(msgSelector.length() != 0){
	        
		        m_subscriber = m_session.createSubscriber(m_topic, msgSelector.toString(), false);
		        
		        //コールバックを登録する
		        m_subscriber.setMessageListener(this);

	        }else{
	        	log.debug("ファシリティ情報がないので、何もしない");
	        }
			

		} catch (Exception e) {
			log.error("TopicInit", e);
			setErrFlg(true);
			return false;
		} finally {
		}
		return true;

	}
	/**
	 * EJB再接続タイマータスク
	 * 通信エラーとなった場合に定周期で呼ばれ再接続を行う 
	 */
	protected class ReSetupTask extends TimerTask {

		/**
		 * コネクションクローズ
		 */
		public void run() {
			if (reInitial()) {
				//このタスクをタイマーから解除
				cancel();
			}
		}

	}
	
}
